==> GeneticsBase_1.6.0.tar.gz: GeneticsBase/man/LDband-class.Rd <==
\name{LDband-class}
\docType{class}
\alias{LDband-class}
\alias{head,LDband-method}
\alias{left,LDband-method}
\alias{right,LDband-method}
\alias{show,LDband-method}
\alias{tail,LDband-method}

\title{Class "LDband" ~~~ }
\description{	 ~~ A concise (1-5 lines) description of what the class is.  ~~}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("LDband", ...)}.
	 ~~ describe objects here ~~ 
}
\section{Slots}{
	 \describe{
    \item{\code{call}:}{Function call used to generate this object.}
    \item{\code{D}:}{Linkage disequilibrium estimate}
    \item{\code{D'}:}{Scaled linkage disequilibrium estimate }
    \item{\code{r}:}{Correlation coefficient}
    \item{\code{R^2}:}{squared correlation coefficient}
    \item{\code{n}:}{Number of observations}
    \item{\code{X^2}:}{Chi-square statistic for linkage
  equilibrium (i.e., D=D'=corr=0)}
    \item{\code{P-value}:}{Chi-square p-value for marker independence}
    \item{\code{LOD}:}{LOD scores}
  }
}
\section{Methods}{
  \describe{
    \item{head}{\code{signature(x = "LDband")}: ... }
    \item{left}{\code{signature(x = "LDband")}: ... }
    \item{right}{\code{signature(x = "LDband")}: ... }
    \item{show}{\code{signature(object = "LDband")}: ... }
    \item{tail}{\code{signature(x = "LDband")}: ... }
	 }
}
\author{Gregory R. Warnes \email{warnes@bst.rochester.edu} and Nitin Jain \email{nitin.jain@pfizer.com}}
\note{ ~~further notes~~ }
\seealso{
}
\examples{
##---- Should be DIRECTLY executable !! ----
}
\keyword{classes}

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/man/LDband-class.Rd <==
\name{LDband-class}
\docType{class}
\alias{LDband-class}
\alias{head,LDband-method}
\alias{left,LDband-method}
\alias{right,LDband-method}
\alias{show,LDband-method}
\alias{tail,LDband-method}

\title{Class "LDband" ~~~ }
\description{	 ~~ A concise (1-5 lines) description of what the class is.  ~~}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("LDband", ...)}.
	 ~~ describe objects here ~~ 
}

\section{Slots}{
  \describe{
    \item{\code{call}:}{Function call used to generate this object.}
    \item{\code{D}:}{Linkage disequilibrium estimate}
    \item{\code{\special{D'}}:}{Scaled linkage disequilibrium estimate}
    \item{\code{r}:}{Correlation coefficient}
    \item{\code{R^2}:}{Squared correlation coefficient}
    \item{\code{n}:}{Number of observations}
    \item{\code{X^2}:}{Chi-square statistic for linkage equilibrium (i.e.,
         D=\special{D'}=corr=0)} 
    \item{\code{P-value}:}{Chi-square p-value for marker independence}
    \item{\code{LOD}:}{LOD scores}
  }
}

\section{Methods}{
  \describe{
    \item{head}{\code{signature(x = "LDband")}: ... }
    \item{left}{\code{signature(x = "LDband")}: ... }
    \item{right}{\code{signature(x = "LDband")}: ... }
    \item{show}{\code{signature(object = "LDband")}: ... }
    \item{tail}{\code{signature(x = "LDband")}: ... }
	 }
}
\author{Gregory R. Warnes \email{warnes@bst.rochester.edu} and Nitin Jain \email{nitin.jain@pfizer.com}}
\note{ ~~further notes~~ }
\seealso{
}
\examples{
##---- Should be DIRECTLY executable !! ----
}
\keyword{classes}
